From 16f182bf4bfe071b846a47f157721b91f6fc31bb Mon Sep 17 00:00:00 2001
From: James Coleman <jtc331@gmail.com>
Date: Tue, 31 Mar 2020 21:39:45 -0400
Subject: [PATCH v49 7/7] rename pathkeys_common_contained_in

---
 src/backend/optimizer/path/allpaths.c |  2 +-
 src/backend/optimizer/path/pathkeys.c |  6 +++---
 src/backend/optimizer/plan/planner.c  | 14 +++++++-------
 src/include/optimizer/paths.h         |  2 +-
 4 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/src/backend/optimizer/path/allpaths.c b/src/backend/optimizer/path/allpaths.c
index b332e474b8..bd786dafd7 100644
--- a/src/backend/optimizer/path/allpaths.c
+++ b/src/backend/optimizer/path/allpaths.c
@@ -2849,7 +2849,7 @@ generate_useful_gather_paths(PlannerInfo *root, RelOptInfo *rel, bool override_r
 			if (subpath->pathkeys == NIL)
 				continue;
 
-			is_sorted = pathkeys_common_contained_in(useful_pathkeys,
+			is_sorted = pathkeys_count_contained_in(useful_pathkeys,
 													 subpath->pathkeys,
 													 &presorted_keys);
 
diff --git a/src/backend/optimizer/path/pathkeys.c b/src/backend/optimizer/path/pathkeys.c
index a3f6828436..21e3f5a987 100644
--- a/src/backend/optimizer/path/pathkeys.c
+++ b/src/backend/optimizer/path/pathkeys.c
@@ -335,12 +335,12 @@ pathkeys_contained_in(List *keys1, List *keys2)
 }
 
 /*
- * pathkeys_common_contained_in
+ * pathkeys_count_contained_in
  *    Same as pathkeys_contained_in, but also sets length of longest
  *    common prefix of keys1 and keys2.
  */
 bool
-pathkeys_common_contained_in(List *keys1, List *keys2, int *n_common)
+pathkeys_count_contained_in(List *keys1, List *keys2, int *n_common)
 {
 	int			n = 0;
 	ListCell   *key1,
@@ -1856,7 +1856,7 @@ pathkeys_useful_for_ordering(PlannerInfo *root, List *pathkeys)
 	if (pathkeys == NIL)
 		return 0;				/* unordered path */
 
-	(void) pathkeys_common_contained_in(root->query_pathkeys, pathkeys,
+	(void) pathkeys_count_contained_in(root->query_pathkeys, pathkeys,
 										&n_common_pathkeys);
 
 	return n_common_pathkeys;
diff --git a/src/backend/optimizer/plan/planner.c b/src/backend/optimizer/plan/planner.c
index 6592d0446d..d6ca896ec3 100644
--- a/src/backend/optimizer/plan/planner.c
+++ b/src/backend/optimizer/plan/planner.c
@@ -4972,7 +4972,7 @@ create_ordered_paths(PlannerInfo *root,
 		bool		is_sorted;
 		int			presorted_keys;
 
-		is_sorted = pathkeys_common_contained_in(root->sort_pathkeys,
+		is_sorted = pathkeys_count_contained_in(root->sort_pathkeys,
 												 input_path->pathkeys, &presorted_keys);
 
 		if (is_sorted)
@@ -5105,7 +5105,7 @@ create_ordered_paths(PlannerInfo *root,
 				 * full sort, which is what happens above).
 				 */
 
-				is_sorted = pathkeys_common_contained_in(root->sort_pathkeys,
+				is_sorted = pathkeys_count_contained_in(root->sort_pathkeys,
 														 input_path->pathkeys,
 														 &presorted_keys);
 
@@ -6567,7 +6567,7 @@ add_paths_to_grouping_rel(PlannerInfo *root, RelOptInfo *input_rel,
 			/* Restore the input path (we might have added Sort on top). */
 			path = path_original;
 
-			is_sorted = pathkeys_common_contained_in(root->group_pathkeys,
+			is_sorted = pathkeys_count_contained_in(root->group_pathkeys,
 													 path->pathkeys,
 													 &presorted_keys);
 
@@ -6694,7 +6694,7 @@ add_paths_to_grouping_rel(PlannerInfo *root, RelOptInfo *input_rel,
 				/* Restore the input path (we might have added Sort on top). */
 				path = path_original;
 
-				is_sorted = pathkeys_common_contained_in(root->group_pathkeys,
+				is_sorted = pathkeys_count_contained_in(root->group_pathkeys,
 														 path->pathkeys,
 														 &presorted_keys);
 
@@ -7013,7 +7013,7 @@ create_partial_grouping_paths(PlannerInfo *root,
 				bool		is_sorted;
 				int			presorted_keys;
 
-				is_sorted = pathkeys_common_contained_in(root->group_pathkeys,
+				is_sorted = pathkeys_count_contained_in(root->group_pathkeys,
 														 path->pathkeys,
 														 &presorted_keys);
 
@@ -7112,7 +7112,7 @@ create_partial_grouping_paths(PlannerInfo *root,
 			/* Restore the input path (we might have added Sort on top). */
 			path = path_original;
 
-			is_sorted = pathkeys_common_contained_in(root->group_pathkeys,
+			is_sorted = pathkeys_count_contained_in(root->group_pathkeys,
 													 path->pathkeys,
 													 &presorted_keys);
 
@@ -7289,7 +7289,7 @@ gather_grouping_paths(PlannerInfo *root, RelOptInfo *rel)
 		int			presorted_keys;
 		double		total_groups;
 
-		is_sorted = pathkeys_common_contained_in(root->group_pathkeys,
+		is_sorted = pathkeys_count_contained_in(root->group_pathkeys,
 												 path->pathkeys,
 												 &presorted_keys);
 
diff --git a/src/include/optimizer/paths.h b/src/include/optimizer/paths.h
index c4f77d5137..c7bd30a8bf 100644
--- a/src/include/optimizer/paths.h
+++ b/src/include/optimizer/paths.h
@@ -191,7 +191,7 @@ typedef enum
 
 extern PathKeysComparison compare_pathkeys(List *keys1, List *keys2);
 extern bool pathkeys_contained_in(List *keys1, List *keys2);
-extern bool pathkeys_common_contained_in(List *keys1, List *keys2, int *n_common);
+extern bool pathkeys_count_contained_in(List *keys1, List *keys2, int *n_common);
 extern Path *get_cheapest_path_for_pathkeys(List *paths, List *pathkeys,
 											Relids required_outer,
 											CostSelector cost_criterion,
-- 
2.17.1

